from __future__ import division
import ROOT as root
from atlasplots import atlas_style as astyle

from signalhisto import signal_histo, signal_analysis
from datahisto import data_histo, data_analysis
from xidatahisto import xidata_analysis
from xiafphisto import xiafp_analysis
from utils import get_efficiency

astyle.SetAtlasStyle()

def invmass_legend(data, signal):
    legend = root.TLegend(0.65, 0.8, 0.85, 0.7)
    legend.AddEntry(data, "Data 2017, HIGG1D", "lep")
    legend.AddEntry(signal, "1 TeV ALP C=0.001", "f")
    legend.SetTextSize(0.037)
    legend.SetTextFont(42)
    legend.SetLineWidth(0)

    return legend

def invmass_analysis(photon_trees):
    canvas = root.TCanvas('coverlap', 'InvMass Histograms', 200, 10, 800, 600)
    canvas.cd(); canvas.SetLogy(); canvas.Print("invmass.pdf[")

    signal_hist = signal_histo(photon_trees[0])
    signal_hist.Draw("h")
    data_hist = data_histo(photon_trees[1])
    data_hist.Draw("pe, same")

    astyle.ATLASLabel(0.65, 0.85, "Internal")
    legend = invmass_legend(data_hist, signal_hist); legend.Draw("same")
    canvas.Print("invmass.pdf"); canvas.Print("invmass.pdf]")

    return canvas

def hist_photon(root_file_paths, analysis):
    trees = []; root_files = []
    for file in root_file_paths:
        root_file = root.TFile.Open(file, "READ")
        root_files.append(root_file)
        photon_tree = root_file.Get("TreePhoton")
        trees.append(photon_tree)

    canvas = analysis(trees); canvas.SetFolder(0)
    for file in root_files: file.Close()

    return canvas

def hist_proton(root_file_paths, analysis):
    trees = []; root_files = []
    for file in root_file_paths:
        root_file = root.TFile.Open(file, "READ")
        root_files.append(root_file)
        proton_tree = root_file.Get("TreeProton")
        trees.append(proton_tree)

    canvas = analysis(trees); canvas.SetFolder(0)
    for file in root_files: file.Close()

    return canvas

if __name__ == '__main__':
    root.gBenchmark.Start('production')
    root.gSystem.ChangeDirectory("histo")
    #invmass_hist = create_hist(["data/signal.root", "data/data.root"], invmass_analysis)
    #xidata_hist = create_hist(["data/data.root"], xidata_analysis)
    #xiafp_hist = create_hist_afp(["data/afpaux.root"], xiafp_analysis)
    genlevel_hist = hist_photon(["../data/signal.root"], signal_analysis)

    output_file = root.TFile.Open("histograms.root", "RECREATE")
    output_file.cd()
    output_file.Close()

    root.gBenchmark.Show('production')
