from __future__ import division
import ROOT as root
from atlasplots import atlas_style as astyle

from utils import get_efficiency
from cuts import kinda_light_by_light_cuts

def signal_analysis_legend(signal):
    legend = root.TLegend(0.65, 0.71, 0.85, 0.75)
    legend.AddEntry(signal, " Signal MC", 'f')
    legend.SetTextSize(0.037)
    legend.SetTextFont(42)
    legend.SetLineWidth(0)

    return legend

def signal_histo(photon_tree):
    mgg = root.TH1D("signal", "Invariant mass of photon pair", 20, 990, 1010)
    mgg.Sumw2();
    mgg.SetLineColor(root.kRed); mgg.SetLineWidth(2)
    mgg.GetYaxis().SetTitle("Events / GeV");
    mgg.GetXaxis().SetTitle("m_{\\gamma\\gamma} [GeV]")
    mgg.SetMarkerSize(0); mgg.SetFillColor(root.kWhite)
    mgg.GetXaxis().SetNdivisions(4)

    valid_events = 0; total_events = photon_tree.GetEntries()
    for event in photon_tree:
        if kinda_light_by_light_cuts(event) is True:
            valid_events += 1
            mgg.Fill(event.PhotonInvMass*(10**(-9)))
        if valid_events == 500: break
    mgg.Scale(180/total_events)
    get_efficiency(valid_events, total_events)

    return mgg

def signal_analysis(photon_trees):
    canvas = root.TCanvas('csignal', 'Signal Histograms', 200, 10, 800, 600)
    canvas.cd(); canvas.SetLogy(); canvas.Print("signal.pdf[")

    signal_histogram = signal_histo(photon_trees[0]); signal_histogram.Draw("h")

    astyle.ATLASLabel(0.67, 0.85, "Internal")
    legend = signal_analysis_legend(signal_histogram); legend.Draw("same")
    canvas.Print("signal.pdf"); canvas.Print("signal.pdf]")

    return canvas
